`grep` examples

These examples show how `grep` should work on the birds and fish lists provided with the starter code.

    In []:grep('birds.txt', 'er', 'birds.txt.er')

    Filebirds.txt.er
    tern
    tanager

    In []:grep('fish.txt', 'er', 'fish.txt.er')

    Filefish.txt.er
    mackerel
    angler fish
    lantern fish

    In []:grep('dir/mammals.txt', 'er', 'dir/mammals.txt.er')

    Filedir/mammals.txt.er
    panther